@@ -1,8 +1,7 @@
 
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 
-from . import ferry
-from ferry import *
+from .ferry import *
 from .meta import *
 from .nodes import *
 from .terrors import *
@@ -13,4 +12,4 @@ __all__ = [*ferry.__all__,
            *nodes.__all__,
            *terrors.__all__,
            *validation.__all__
-           ]           
\ No newline at end of file
+           ]           
